# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupBlacklistRecord.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aGroupBlacklistRecord.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xc5\x01\n\x14GroupBlacklistRecord\x12\n\n\x02id\x18\x01 \x01(\x03\x12+\n\x08operator\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12)\n\x06target\x18\x03 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x0f\n\x07groupId\x18\x04 \x01(\t\x12\x10\n\x08subBizId\x18\x05 \x01(\x05\x12\x12\n\ncreateTime\x18\x06 \x01(\x03\x12\x12\n\nupdateTime\x18\x07 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupBlacklistRecord_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPBLACKLISTRECORD._serialized_start=72
  _GROUPBLACKLISTRECORD._serialized_end=269
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Attachments.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Attachment_pb2 as Attachment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x41ttachments.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x41ttachment.proto\"E\n\x0b\x41ttachments\x12\x36\n\x0b\x61ttachments\x18\x01 \x03(\x0b\x32!.AcFunDanmu.Im.Message.Attachmentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Attachments_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ATTACHMENTS._serialized_start=62
  _ATTACHMENTS._serialized_end=131
# @@protoc_insertion_point(module_scope)
